# follow pep-386
# Examples:
# * 0.3     - released version
# * 0.3a1   - alpha version
# * 0.3.dev - version in development
__version__ = '1.0'
__releasedate__ = '30-10-2013'
